Crate portal_pc_waffle_ir

Crate portal_pc_waffle_ir 

Core IR (Intermediate Representation) for WAFFLE Wasm analysis framework.

Re-exports

pub use op_traits::SideEffect;
pub use op_traits::op_inputs;
pub use op_traits::op_outputs;
pub use waffle_entity as entity;
pub use wasmparser;
pub use wasm_encoder;
pub use ir::*;
pub use interp::*;

Modules

arena_traits
cfg
Lightweight CFG analyses.
interp
Waffle IR interpreter.
ir
op_traits
Metadata on operators.
pool
Pooled list data structure.
scoped_map
Scoped hashmap.
util

Macros

declare_entity

Structs

Block
ControlTag
EntityVec
Func
Global
Ieee32
An IEEE binary32 immediate floating point value, represented as a u32 containing the bit pattern.
Ieee64
An IEEE binary64 immediate floating point value, represented as a u64 containing the bit pattern.
ListPool
A “storage pool” backing many ListRefs of the given type.
ListRef
A handle to a list stored in a ListPool.
Local
Memory
MemoryArg
An argument to a memory load or store, specifying which memory, alignment and an optional offset.
PerEntity
Vector of state per entity in an index-space that does not define the index-space. In other words, this container will not pass out new indices, it will only allow associating state with existing indices; and it requires a default value for data at an index not yet assigned.
Signature
Table
Value
WithMutablility
Something, alsong with whether it can be mutated
WithNullable
Something, alsong with whether it can be null

Enums

FrontendError
An error that occurs when translating Wasm to IR.
Handler
An exception’s handler
HeapType
a Type that can be stored on the heap
Operator
An operator in the IR, consuming arguments and producing results when executed.
StorageType
A storage type
Type
Types in waffle’s IR.

Traits

EntityRef
An index into an index-space of entities.
Subtypes